@@ -1,3 +1,4 @@
+from .intensity_fitter import MuonIntensityFitter
 from .plot_muon import plot_muon_event
 from .muon_analysis import (
     analyze_muon_event,
@@ -6,16 +7,13 @@ from .muon_analysis import (
     fill_muon_event,
     pixel_coords_to_telescope,
 )
-from .muon_integrator import (
-    MuonLineIntegrate,
-)
 
 __all__ = [
+    'MuonIntensityFitter',
     'analyze_muon_event',
     'tag_pix_thr',
     'create_muon_table',
     'fill_muon_event',
     'plot_muon_event',
     'pixel_coords_to_telescope',
-    'MuonLineIntegrate',
 ]
