@@ -1,4 +1,4 @@
-from ctapipe.io.containers import DataContainer
+from ctapipe.containers import DataContainer
 import numpy as np
 from lstchain.reco.r0_to_dl1 import rescale_dl1_charge
 from copy import copy
@@ -15,4 +15,4 @@ def test_rescale_dl1_charge():
     rescale_dl1_charge(event, rescaling_factor)
 
     for tel_id in tel_ids:
-        np.testing.assert_allclose(event.dl1.tel[tel_id].image, images[tel_id]*rescaling_factor)
\ No newline at end of file
+        np.testing.assert_allclose(event.dl1.tel[tel_id].image, images[tel_id]*rescaling_factor)
