@@ -18,10 +18,8 @@ $> python lstchain_muon_analysis_dl1.py
 
 import argparse
 import glob
-import os
 import numpy as np
 from ctapipe.instrument import CameraGeometry
-from astropy import units as u
 
 from lstchain.image.muon import (
     analyze_muon_event,
@@ -29,12 +27,13 @@ from lstchain.image.muon import (
     fill_muon_event,
     tag_pix_thr,
 )
-from lstchain.io.io import dl1_params_lstcam_key
+
 from lstchain.visualization import plot_calib
+from lstchain.io.io import dl1_params_lstcam_key, dl1_images_lstcam_key
+from lstchain.io.io import read_telescopes_descriptions, read_subarray_description
 
 from astropy.table import Table
 import pandas as pd
-import tables
 
 parser = argparse.ArgumentParser()
 
@@ -111,6 +110,8 @@ def main():
     filenames = glob.glob(args.input_file)
     filenames.sort()
 
+    lst1_tel_id = 1
+
     num_muons = 0
 
     for filename in filenames:
@@ -119,67 +120,69 @@ def main():
         cam_description_table = Table.read(filename, path="instrument/telescope/camera/LSTCam")
         geom = CameraGeometry.from_table(cam_description_table)
 
-        with tables.open_file(filename) as file:
+        subarray = read_subarray_description(filename, subarray_name='LST-1')
 
-            # unfortunately pandas.read_hdf does not seem compatible with "with... as..." statements
-            parameters = pd.read_hdf(filename, key = dl1_params_lstcam_key)
-            telescope_description = pd.read_hdf(filename, key='instrument/telescope/optics')
+        images = Table.read(filename, path=dl1_images_lstcam_key)['image']
 
-            group = file.root.dl1.event.telescope.image.LST_LSTCam
-            images = [x['image'] for x in group.iterrows()]
+        parameters = pd.read_hdf(filename, key=dl1_params_lstcam_key)
+        telescope_description = read_telescopes_descriptions(filename)[lst1_tel_id]
 
-            equivalent_focal_length = telescope_description['equivalent_focal_length'].values * u.m
-            mirror_area = telescope_description['mirror_area'].values * pow(u.m,2)
+        equivalent_focal_length = telescope_description.optics.equivalent_focal_length
+        mirror_area = telescope_description.optics.mirror_area
 
-            # fill dummy event times with NaNs in case they do not exist (like in MC):
-            if 'dragon_time' not in parameters.keys():
-                dummy_times = np.empty(len(parameters['event_id']))
-                dummy_times[:] = np.nan
-                parameters['dragon_time'] = dummy_times
+        # fill dummy event times with NaNs in case they do not exist (like in MC):
+        if 'dragon_time' not in parameters.keys():
+            dummy_times = np.empty(len(parameters['event_id']))
+            dummy_times[:] = np.nan
+            parameters['dragon_time'] = dummy_times
 
-            for full_image, event_id, dragon_time in zip(images, parameters['event_id'], parameters['dragon_time']):
-                if args.calib_file is not None:
-                    image = full_image*(~bad_pixels)
-                else:
-                    image = full_image
-                # print("Event {}. Number of pixels above 10 phe: {}".format(event_id,
-                #                                                           np.size(image[image > 10.])))
-                # if((np.size(image[image > 10.]) > 300) or (np.size(image[image > 10.]) < 50)):
-                #     continue
-                if not tag_pix_thr(image): # default skips pedestal and calibration events
-                    continue
+        for full_image, event_id, dragon_time, mc_energy in zip(
+                images, parameters['event_id'], parameters['dragon_time'], parameters['mc_energy']):
+            if args.calib_file is not None:
+                image = full_image*(~bad_pixels)
+            else:
+                image = full_image
+            # print("Event {}. Number of pixels above 10 phe: {}".format(event_id,
+            #                                                           np.size(image[image > 10.])))
+            # if((np.size(image[image > 10.]) > 300) or (np.size(image[image > 10.]) < 50)):
+            #     continue
+            if not tag_pix_thr(image): # default skips pedestal and calibration events
+                continue
 
-                # default values apply no filtering.
-                # This filter is rather useless for biased extractors anyway
-                # if not muon_filter(image)
-                #    continue
+            # default values apply no filtering.
+            # This filter is rather useless for biased extractors anyway
+            # if not muon_filter(image)
+            #    continue
 
-                (
-                    muonintensityparam, size_outside_ring, muonringparam, good_ring,
-                    radial_distribution, mean_pixel_charge_around_ring,
-                ) = analyze_muon_event(
-                    event_id, image, geom, equivalent_focal_length,
-                    mirror_area, args.plot_rings, args.plots_path
-                )
+            (
+                muonintensityparam, dist_mask, size, size_outside_ring,
+                muonringparam, good_ring, radial_distribution,
+                mean_pixel_charge_around_ring, muonparameters
+            ) = analyze_muon_event(subarray,
+                event_id, image, geom, equivalent_focal_length,
+                mirror_area, args.plot_rings, args.plots_path
+            )
 
-                if good_ring:
-                    num_muons += 1
-                    print("Number of good muon rings found {}, EventID {}".format(num_muons, event_id))
+            if good_ring:
+                num_muons += 1
+                print("Number of good muon rings found {}, EventID {}".format(num_muons, event_id))
 
-                # write ring data, including also "not-so-good" rings
-                # in case we want to reconsider ring selections!:
-                fill_muon_event(
-                    output_parameters, good_ring, event_id, dragon_time,
-                    muonintensityparam, muonringparam, radial_distribution,
-                    size_outside_ring, mean_pixel_charge_around_ring,
-                )
-
-                if max_muons is not None and num_muons == max_muons:
-                    break
+            # write ring data, including also "not-so-good" rings
+            # in case we want to reconsider ring selections!:
+            fill_muon_event(
+                mc_energy, output_parameters, good_ring, event_id,
+                dragon_time, muonintensityparam, dist_mask,
+                muonringparam, radial_distribution, size,
+                size_outside_ring, mean_pixel_charge_around_ring,
+                muonparameters
+            )
 
             if max_muons is not None and num_muons == max_muons:
                 break
 
+        if max_muons is not None and num_muons == max_muons:
+            break
+
     table = Table(output_parameters)
     table.write(args.output_file, format='fits', overwrite=True)
 
